api.system.notification.v1.test_helpers.events package — Argus-Toolbelt 1.0 documentation

# api.system.notification.v1.test_helpers.events package

## Submodules

## api.system.notification.v1.test_helpers.events.list_events module

`api.system.notification.v1.test_helpers.events.list_events.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/events, respond with HTTP 403

`api.system.notification.v1.test_helpers.events.list_events.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/events, respond with HTTP 404

`api.system.notification.v1.test_helpers.events.list_events.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/events, respond with HTTP 200

`api.system.notification.v1.test_helpers.events.list_events.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/events, respond with HTTP 401

## Module contents